############################################################
#
# $Id: test_pyhl.py,v 1.3 2000/04/11 10:51:40 ahenja Exp dmichels $
#
# Description:	Example code for working with the pyhl module.
#
# Author(s):	Anders Henja
#
# Copyright:	Swedish Meteorological and Hydrological Institute, 2000
#
# History:	2000-03-22 Created by Anders Henja
############################################################
import _pyhl
from Numeric import *

def test_writenodelist():
    a=_pyhl.nodelist()

    b=_pyhl.node(_pyhl.GROUP_ID,"/info")
    a.addNode(b)

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/xscale")
    b.setScalarValue(-1,10.0,"double",-1)
    a.addNode(b)

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/yscale")
    b.setScalarValue(-1,19.0,"double",-1)
    a.addNode(b);

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/xsize")
    b.setScalarValue(-1,15,"int",-1)
    a.addNode(b)

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/ysize")
    b.setScalarValue(-1,20,"int",-1)
    a.addNode(b)

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/pcs_def")
    b.setScalarValue(-1,"min strang funktion verkar fungera","string",-1)
    a.addNode(b)

    c=arange(110)
    c=array(c.astype('b'),'b')
    c=reshape(c,(10,11))
    print "ARRAY WRITTEN = " + `c`
    b=_pyhl.node(_pyhl.DATASET_ID,"/data")
    b.setArrayValue(1,[10,11],c,"uchar",-1)
    a.addNode(b)

    a.write("testskrivning.hdf")

def test_readnodelist():
    a=_pyhl.read_nodelist("testskrivning.hdf")
    b=a.getNodeNames()
    a.selectNode("/info/xscale")
    a.selectNode("/info/yscale")
    a.selectNode("/info/pcs_def")
    a.selectNode("/data")
    a.fetch()
    c=a.getNode("/info/xscale")
    d=c.data()
    print "XSCALE="+`d`
    c=a.getNode("/info/pcs_def");
    d=c.data()
    print "PCS_DEF="+`d`
    #print `b`
    print "NODENAME=" + c.name()
    print "DIMS=" + `c.dims()`
    print "FORMAT=" + c.format()
    c=a.getNode("/data")
    print "NODENAME=" + c.name()
    print "DIMS=" + `c.dims()`
    print "FORMAT=" + c.format()
    d=c.data()
    print `d`

def test_readwrite():
    a = _pyhl.nodelist()
    b = _pyhl.read_nodelist("testskrivning.hdf")
    b.selectAll()
    b.fetch()

    c = b.getNode("/info")
    a.addNode(c)
    c = b.getNode("/info/xscale")
    a.addNode(c)
    c = b.getNode("/data")
    a.addNode(c)
    a.write("small_copy.hdf")

def memory_check_write():
    a=_pyhl.nodelist()
    b=_pyhl.node(_pyhl.GROUP_ID,"/info")
    a.addNode(b)

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/charval")
    b.setScalarValue(-1,1,"char",-1)
    a.addNode(b)

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/shortval")
    b.setScalarValue(-1,2,"short",-1)
    a.addNode(b)

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/intval")
    b.setScalarValue(-1,3,"int",-1)
    a.addNode(b)

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/longval")
    b.setScalarValue(-1,4,"long",-1)
    a.addNode(b)

    #b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/longlongval")
    #b.setScalarValue(-1,5,"llong",-1)
    #a.addNode(b)

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/floatval")
    b.setScalarValue(-1,6.1,"float",-1)
    a.addNode(b)

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/doubleval")
    b.setScalarValue(-1,7.2,"double",-1)
    a.addNode(b)

    b=_pyhl.node(_pyhl.ATTRIBUTE_ID,"/info/stringval")
    b.setScalarValue(-1,"hej hopp i lingonskogen","string",-1)
    a.addNode(b)

    c=arange(100)
    c=array(c.astype('i'),'i')
    c=reshape(c,(10,10))
    b=_pyhl.node(_pyhl.DATASET_ID,"/info/dataset")
    b.setArrayValue(1,[10,10],c,"int",-1)
    a.addNode(b)

    a.write("memtest_skrivning.hdf")

    del a
    del b
    del c

def memory_check_read():
    a=_pyhl.read_nodelist("memtest_skrivning.hdf")
    a.selectAll()
    a.fetch()
    names=a.getNodeNames()
    for key in names.keys():
    	b=a.getNode(key)
    	del b
    del names
    del a

if __name__=="__main__":
    test_writenodelist()
    #test_readnodelist()
    #test_readnodelist()
    #test_readwrite()
    #for i in range(0,10000):
    #	if i%100==0:
    #	    print "Working with i = %s" % i
    #	memory_check_write()
##     for i in range(0,10000):
## 	if i%100==0:
## 	    print "Working with i = %s" % i
## 	memory_check_read()

